@@ -7,8 +7,8 @@
 """
 
 import json
-from os import environ
 from collections import OrderedDict
+from os import environ
 from typing import (
     Dict,
     Union
@@ -30,12 +30,16 @@ class HttpBody:
         schema: Union[ConfigSchema, ConfigExternalFilePath, None],
         text: Union[str, None],
         urlencoded: Union[Dict[str, str], None],
-        multipart: Union[Dict[str, str], None]
+        multipart: Union[Dict[str, str], None],
+        graphql_variables: Union[Dict[str, str], None],
+        is_grapql_query: bool = False
     ):
         self.schema = schema
         self.text = text
         self.urlencoded = urlencoded
         self.multipart = multipart
+        self.graphql_variables = graphql_variables
+        self.is_graphql_query = is_grapql_query
 
     def oas(self, handler) -> Union[dict, None]:
         request_body = None
